# Generated by roxygen2: do not edit by hand

export(arvind_mean_fn)
export(arvind_var_fn)
export(cv_arvind)
export(darvind)
export(diagnostics_arvind)
export(fit_arvind_mle)
export(fit_hmm)
export(fit_mixed)
export(fit_rw1)
export(fit_simex)
export(fit_tvlm)
export(forecast_arvind)
export(parvind)
export(plot_arvind)
export(qarvind)
export(rarvind)
export(rarvind_centred)
export(simulate_arvind_data)
export(summary_arvind)
importFrom(grDevices,dev.off)
importFrom(grDevices,png)
importFrom(graphics,hist)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(rlang,.data)
importFrom(stats,Box.test)
importFrom(stats,acf)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,density)
importFrom(stats,dnorm)
importFrom(stats,ecdf)
importFrom(stats,fitted)
importFrom(stats,gaussian)
importFrom(stats,integrate)
importFrom(stats,ks.test)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,optim)
importFrom(stats,optimize)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,simulate)
importFrom(stats,terms)
importFrom(stats,ts)
importFrom(stats,uniroot)
importFrom(stats,var)
importFrom(utils,head)
importFrom(utils,tail)
