#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom stats acf coef dnorm ecdf fitted lm model.frame model.matrix
#'   model.response optim optimize predict quantile rnorm runif sd
#'   simulate terms ts uniroot var as.formula integrate density gaussian median
#' @importFrom stats Box.test ks.test
#' @importFrom graphics hist lines legend
#' @importFrom grDevices dev.off png
#' @importFrom utils head tail
#' @importFrom rlang .data
## usethis namespace: end
NULL
