% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/arvind_distribution.R
\name{parvind}
\alias{parvind}
\title{Arvind Distribution Function (CDF)}
\usage{
parvind(q, theta, lower.tail = TRUE)
}
\arguments{
\item{q}{numeric vector of quantiles.}

\item{theta}{positive numeric scalar; the distribution parameter.}

\item{lower.tail}{logical; if \code{TRUE} (default), probabilities are
\eqn{P(X \le q)}{P(X <= q)}; otherwise \eqn{P(X > q)}.}
}
\value{
A numeric vector of probabilities.
}
\description{
Computes the cumulative distribution function (CDF) of the Arvind
distribution.
}
\details{
The CDF is given by
\deqn{F(x; \theta) = 1 - \frac{1}{1 + \theta x} \exp(-\theta x^2),
  \quad x > 0.}
}
\examples{
parvind(1, theta = 1)
parvind(c(0.5, 1, 2), theta = 2)
parvind(1, theta = 1, lower.tail = FALSE)

}
